# OctoBot-Launcher [2.0.2](https://github.com/Drakkar-Software/OctoBot-Launcher/tree/master/CHANGELOG.md)
[![PyPI](https://img.shields.io/pypi/v/OctoBot-Launcher.svg)](https://pypi.python.org/pypi/OctoBot-Launcher/)
[![Downloads](https://pepy.tech/badge/octobot-launcher/month)](https://pepy.tech/project/octobot-launcher)
[![Release](https://img.shields.io/github/downloads/Drakkar-Software/OctoBot-Launcher/total.svg)](https://github.com/Drakkar-Software/OctoBot-Launcher/releases)
[![Build Status](https://api.travis-ci.org/Drakkar-Software/OctoBot-Launcher.svg?branch=master)](https://travis-ci.org/Drakkar-Software/OctoBot-Launcher) 
[![Build status](https://ci.appveyor.com/api/projects/status/bcb75xy9dch6c3nx?svg=true)](https://ci.appveyor.com/project/Herklos/octobot-Launcher)


A launcher for your [OctoBot](https://github.com/Drakkar-Software/OctoBot) ! 

![Demo](../assets/octobot_launcher.gif)

## Usage
- Install OctoBot by pressing "Install/Update OctoBot"
- To start OctoBot : "Start OctoBot" and wait for a new window and then click on "Open OctoBot"
- Update launcher with "Update Launcher"

## Install

### [With binary](https://github.com/Drakkar-Software/OctoBot-Launcher/releases)
**For 64 bits systems only**
- Download [latest release](https://github.com/Drakkar-Software/OctoBot-Launcher/releases)
- On Windows : double click on launcher_windows.exe
- On Linux : 
``` {.sourceCode .bash}
$ chmox +x launcher_linux
$ ./launcher_linux
```

### Without binary
Install [Python 3.7](https://www.python.org/downloads/) and then type in a command line : 
``` {.sourceCode .bash}
$ python -m pip install OctoBot-Launcher
$ octobot-launcher
```
